
# Changelog
All notable changes to WuttaPOS will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## v0.4.0 (2026-01-03)

First release under the new project.

The server app works, but does little.  Same for the terminal app.
